@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '2.04';
+$HTTP::BrowserDetect::VERSION = '2.05';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -24,9 +24,10 @@ our @WINDOWS_TESTS = qw(
     winme      win32        win2k
     winxp      win2k3       winvista
     win7       win8         win8_0
-    win8_1     wince        winphone
-    winphone7  winphone7_5  winphone8
-    winphone8_1
+    win8_1     win10        win10_0
+    wince      winphone     winphone7
+    winphone7_5 winphone8   winphone8_1
+    winphone10
 );
 
 # More precise Mac
@@ -75,6 +76,7 @@ our @BROWSER_TESTS = qw(
     webtv          browsex     silk
     applecoremedia galeon      seamonkey
     epiphany       ucbrowser   dalvik
+    edge
 );
 
 our @IE_TESTS = qw(
@@ -111,7 +113,7 @@ our @FIREFOX_TESTS = qw(
 # Engine tests
 our @ENGINE_TESTS = qw(
     gecko       trident     webkit
-    presto      khtml
+    presto      khtml       edgehtml
 );
 
 our @ROBOT_TESTS = qw(
@@ -200,6 +202,7 @@ my %BROWSER_NAMES = (
     curl           => 'curl',
     dalvik         => 'Dalvik',
     dsi            => 'Nintendo DSi',
+    edge           => 'Edge',
     elinks         => 'ELinks',
     epiphany       => 'Epiphany',
     firefox        => 'Firefox',
@@ -271,6 +274,8 @@ my %OS_NAMES = (
     win8        => 'Win8',
     win8_0      => 'Win8.0',
     win8_1      => 'Win8.1',
+    win10       => 'Win10',
+    win10_0     => 'Win10.0',
     win95       => 'Win95',
     win98       => 'Win98',
     winme       => 'WinME',
@@ -461,7 +466,11 @@ sub _init_core {
     # Detect engine
     $self->{engine_version} = undef;
 
-    if ( $ua =~ /trident\/([\w\.\d]*)/ ) {
+    if ( $ua =~ m{edge/([\d.]+)$} ) {
+        $tests->{edgehtml}      = 1;
+        $self->{engine_version} = $1;
+    }
+    elsif ( $ua =~ /trident\/([\w\.\d]*)/ ) {
         $tests->{trident}       = 1;
         $self->{engine_version} = $1;
     }
@@ -501,6 +510,14 @@ sub _init_core {
         $browser = "epiphany";
         $browser_tests->{epiphany} = 1;
     }
+    elsif ( $ua
+        =~ m{^mozilla/.+windows (?:nt|phone) \d{2}\.\d+;.+ applewebkit/.+ chrome/.+ safari/.+ edge/[\d.]+$}
+        ) {
+        $browser        = 'edge';
+        $browser_string = 'Edge';
+
+        $browser_tests->{edge} = 1;
+    }
     elsif (
         $ua =~ m{
                 (firebird|iceweasel|phoenix|namoroka|firefox)
@@ -1060,6 +1077,9 @@ sub _init_os {
             elsif ( index( $ua, "windows phone 8.1" ) != -1 ) {
                 $os_tests->{winphone8_1} = 1;
             }
+            elsif ( index( $ua, "windows phone 10.0" ) != -1 ) {
+                $os_tests->{winphone10} = 1;
+            }
         }
     }
 
@@ -1103,6 +1123,12 @@ sub _init_os {
             $os_tests->{win8_1} = $os_tests->{win8} = $os_tests->{winnt}
                 = $os_tests->{win32} = 1;
         }
+        elsif ( index( $ua, "nt 10.0" ) != -1 ) {
+            $os        = "windows";
+            $os_string = 'Win10.0';
+            $os_tests->{win10_0} = $os_tests->{win10} = $os_tests->{winnt}
+                = $os_tests->{win32} = 1;
+        }
         elsif (index( $ua, "winnt" ) != -1
             || index( $ua, "windows nt" ) != -1
             || index( $ua, "nt4" ) != -1
@@ -1408,6 +1434,9 @@ sub _init_version {
         # Nothing else is going to work if $browser isn't defined; skip the
         # specific approaches and go straight to the generic ones.
     }
+    elsif ( $browser_tests->{edge} ) {
+        ( $major, $minor, $beta ) = $ua =~ m{Edge/(\d+)(.\d+)(.\d+)?};
+    }
     elsif ( $browser_tests->{safari} ) {
 
         # Safari Version
@@ -2157,6 +2186,10 @@ sub engine_string {
         return 'MSIE';
     }
 
+    if ( $self->edge ) {
+        return 'EdgeHTML';
+    }
+
     if ( $self->webkit ) {
         return 'WebKit';
     }
@@ -2404,7 +2437,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 2.04
+version 2.05
 
 =head1 SYNOPSIS
 
@@ -2549,10 +2582,21 @@ do that that's more suitable for use in program logic, see below under
 Returns C<undef> if no OS information could be detected.
 
 =head2 os_version()
+
+Returns Operating System version.
+
 =head2 os_major()
+
+Returns Operating System major version.
+
 =head2 os_minor()
+
+Returns Operating System minor version.
+
 =head2 os_beta()
 
+Returns Operating System beta version.
+
 Returns version information for the OS, if any could be detected. The
 format is the same as for the browser_version() functions.
 
@@ -2668,9 +2712,11 @@ winnt, which is a type of win32)
             win2k winxp win2k3 winvista win7
             win8
                 win8_0 win8_1
+            win10
+                win10_0
     wince
     winphone
-        winphone7 winphone7_5 winphone8
+        winphone7 winphone7_5 winphone8 winphone10
 
 =head3 dotnet()
 
@@ -2935,13 +2981,20 @@ Returns C<undef> if none of the known rendering engines can be
 detected.
 
 =head2 engine_version()
+
+Returns engine's version.
+
 =head2 engine_major()
+
+Returns engine's major version.
+
 =head2 engine_minor()
+
+Returns engine's minor version.
+
 =head2 engine_beta()
 
-Returns version information for the rendering engine, if any can be
-detected. The format is the same as for the browser_version()
-functions.
+Return's engine's beta version.
 
 =head1 Deprecated methods
 
@@ -2994,12 +3047,20 @@ compatibility with earlier code. browser_version() returns correct
 version numbers for Safari.
 
 =head2 public_version()
+
+Deprecated.  Please use browser_version() instead.
+
 =head2 public_major()
+
+Deprecated.  Please use browser_major() instead.
+
 =head2 public_minor()
+
+Deprecated.  Please use browser_minor() instead.
+
 =head2 public_beta()
 
-Deprecated alternate names for the browser_version() family of
-functions.
+Deprecated.  Please use browser_beta() instead.
 
 =head2 gecko_version()
 
@@ -3102,6 +3163,14 @@ Hao Wu
 
 Perlover
 
+Daniel Stadie
+
+ben hengst
+
+Andrew Moise
+
+Atsushi Kato
+
 =head1 TO DO
 
 POD coverage is not 100%.
